@@ -4,8 +4,8 @@ use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '1.1.48'; # VERSION
-our $DATE = '2014-05-28'; # DATE
+our $VERSION = '1.1.49'; # VERSION
+our $DATE = '2014-06-13'; # DATE
 
 our %SCHEMAS;
 
@@ -53,6 +53,7 @@ $SCHEMAS{rinci_function} = [hash => {
             _value_prop => {
                 %dh_props,
 
+                as => {},
                 schema => {},
                 default => {},
                 req => {},
@@ -72,11 +73,12 @@ $SCHEMAS{rinci_function} = [hash => {
                 cmdline_src => {},
             },
         },
-        args_as => {},
+        args_as => {}, # OLD 1.1.48-, replaced with args/as, will be removed in the future
         result => {
             _prop => {
                 %dh_props,
 
+                is_naked => {},
                 schema => {},
                 statuses => {
                     _value_prop => {
@@ -89,7 +91,7 @@ $SCHEMAS{rinci_function} = [hash => {
                 },
             },
         },
-        result_naked => {},
+        result_naked => {}, # OLD 1.1.48-, replaced with result/is_naked, will be removed in the future
         examples => {
             _elem_prop => {
                 %dh_props,
@@ -120,6 +122,8 @@ $SCHEMAS{rinci_function} = [hash => {
                 none => {},
                 env => {},
                 prog => {},
+                pkg => {},
+                func => {},
                 code => {},
                 tmp_dir => {},
                 trash_dir => {},
@@ -147,7 +151,7 @@ Sah::Schema::Rinci - Sah schemas for Rinci metadata
 
 =head1 VERSION
 
-This document describes version 1.1.48 of Sah::Schema::Rinci (from Perl distribution Rinci), released on 2014-05-28.
+This document describes version 1.1.49 of Sah::Schema::Rinci (from Perl distribution Rinci), released on 2014-06-13.
 
 =head1 HOMEPAGE
 
